#
# spec file for package slirp4netns
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           slirp4netns
Version:        0.4.5
Release:        lp151.2.9.1
Summary:        User-mode networking for unprivileged network namespaces
License:        GPL-2.0-only AND MIT AND BSD-2-Clause
Group:          System/Management
URL:            https://github.com/rootless-containers/slirp4netns
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  git
BuildRequires:  glib2-devel
BuildRequires:  go-go-md2man
BuildRequires:  libcap-devel
BuildRequires:  libseccomp-devel
BuildRequires:  make

%description
slirp for network namespaces, without copying buffers across the namespaces.

%prep
%setup -q

%build
./autogen.sh
%configure
make %{?_smp_mflags}
make %{?_smp_mflags} generate-man

%install
install -D -m 0755 %{name} %{buildroot}/%{_bindir}/%{name}
install -d %{buildroot}/%{_mandir}/man1
install -m 0644 %{name}.1 %{buildroot}/%{_mandir}/man1

%files
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*.1%{?ext_man}

%changelog
* Mon May  4 2020 Ralf Haferkamp <rhafer@suse.com>
- Update to 0.4.5 (bsc#1170940)
  * libslirp: update to v4.3.0:
  * Fix use-afte-free in ip_reass() (CVE-2020-1983)
* Fri Mar 27 2020 Ralf Haferkamp <rhafer@suse.com>
- Update to 0.4.4 (bsc#1167850)
  * libslirp: Update to v4.2.0:
  * New API function slirp_add_unix: add a forward rule to a Unix
    socket.
  * New API function slirp_remove_guestfwd: remove a forward rule
    previously added by slirp_add_exec, slirp_add_unix or
    slirp_add_guestfwd
  * New SlirpConfig.outbound_addr{,6} fields to bind output
    socket to a specific address
  * socket: do not fallback on host loopback if get_dns_addr()
    failed or the address is in slirp network
  * ncsi: fix checksum OOB memory access
  * tcp_emu(): fix OOB accesses
  * tftp: restrict relative path access
  * state: fix loading of guestfwd state
* Wed Dec 18 2019 Sascha Grunert <sgrunert@suse.com>
- Update to 0.4.3
  * api: raise an error if the socket path is too long
  * libslirp: update to v4.1.0: Including the fix for libslirp
    sends RST to app in response to arriving FIN when containerized
    socket is shutdown() with SHUT_WR
  * Fix create_sandbox error
* Mon Oct 21 2019 Sascha Grunert <sgrunert@suse.com>
- Update to 0.4.2
  * Do not propagate mounts to the parent ns in sandbox
* Fri Aug 30 2019 Sascha Grunert <sgrunert@suse.com>
- Update to 0.4.1
  * Support specifying netns path (slirp4netns --netns-type=path PATH
    TAPNAME)
  * Support specifying --userns-path
  * Vendor https://gitlab.freedesktop.org/slirp/libslirp (QEMU v4.1+)
  * Bring up loopback device when --configure is specified
  * Support sandboxing by creating a mount namespace
    (--enable-sandbox)
  * Support seccomp (--enable-seccomp)
- Add new build dependencies libcap-devel and libseccomp-devel
* Thu Aug 29 2019 Sascha Grunert <sgrunert@suse.com>
- Update to 0.3.3
  * Fix use-after-free in libslirp
* Wed Aug  7 2019 Sascha Grunert <sgrunert@suse.com>
- Add missing licenses to spec file
* Mon Aug  5 2019 Sascha Grunert <sgrunert@suse.com>
- Update to 0.3.2
  * Fix heap overflow in `ip_reass` on big packet input
* Thu Aug  1 2019 Sascha Grunert <sgrunert@suse.com>
- Update to 0.3.1
  * Fix use-after-free
* Fri Mar 29 2019 Sascha Grunert <sgrunert@suse.com>
- Update to 0.3.0
  * QMP-like JSON API for exposing node ports (--api-socket)
* Wed Mar 20 2019 Richard Brown <rbrown@suse.com>
- Change _service to use releases instead of git commit references
* Mon Mar 18 2019 Oliver Bengs <appleonkel@opensuse.org>
- Update to 0.3.0-beta1
  * Support protecting 127.0.0.1 on the host (--disable-host-loopback)
  * Support specifying CIDR like 10.0.2.0/24 (--cidr)
  * Fix CVE-2019-6778
  * Synced with QEMU upstream
* Wed Oct 17 2018 Valentin Rothberg <vrothberg@suse.com>
- Introduce slirp4netns in version 0.1 to support rootless Podman:
  slirp4netns provides user-mode networking ("slirp") for unprivileged network
  namespaces. A common use-case of slirp4netns is to enable network access for
  rootless container engines such as Podman.
